Entities — python-copr 1.63 documentation

# Entities

Represents domain objects like project or build. The user of `python-copr` is not expected to use the directly.

class `copr.client_v2.entities.` `Link`(role, href)

  Bases: `copr.util.UnicodeMixin`

  classmethod `from_dict`(data_dict)

class `copr.client_v2.entities.` `Entity`(**kwargs)

  Bases: `copr.util.UnicodeMixin`

  `to_dict`()
  `to_json`()
  classmethod `from_dict`(raw_dict)

class `copr.client_v2.entities.` `ProjectEntity`(**kwargs)

  Bases: `copr.client_v2.entities.Entity`

class `copr.client_v2.entities.` `ProjectCreateEntity`(**kwargs)

  Bases: `copr.client_v2.entities.Entity`

class `copr.client_v2.entities.` `ProjectChrootEntity`(**kwargs)

  Bases: `copr.client_v2.entities.Entity`

class `copr.client_v2.entities.` `BuildEntity`(**kwargs)

  Bases: `copr.client_v2.entities.Entity`

  `is_finished`()

    Check is the build was finished

    Return type: | bool

class `copr.client_v2.entities.` `BuildTaskEntity`(**kwargs)

  Bases: `copr.client_v2.entities.Entity`

class `copr.client_v2.entities.` `MockChrootEntity`(**kwargs)

  Bases: `copr.client_v2.entities.Entity`